==> open-parties-and-claims-forge-1.20.4-0.25.10-sources.jar: xaero/pac/common/mixin/MixinForgeMob.java <==
/*
 * Open Parties and Claims - adds chunk claims and player parties to Minecraft
 * Copyright (C) 2022-2026, Xaero <xaero1996@gmail.com> and contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of version 3 of the GNU Lesser General Public License
 * (LGPL-3.0-only) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received copies of the GNU Lesser General Public License
 * and the GNU General Public License along with this program.
 * If not, see <https://www.gnu.org/licenses/>.
 */

package xaero.pac.common.mixin;

import net.minecraft.core.Vec3i;
import net.minecraft.world.entity.Mob;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import xaero.pac.common.server.core.ServerCore;

@Mixin(value = Mob.class, priority = 1000001)
public class MixinForgeMob {

	@Inject(method = "aiStep", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/entity/LivingEntity;aiStep()V", shift = At.Shift.AFTER))
	public void onAiStepPre(CallbackInfo ci){
		ServerCore.forgePreItemMobGriefingCheck((Mob)(Object)this);
	}

	@Inject(method = "aiStep", at = @At("RETURN"))
	public void onAiStepPost(CallbackInfo ci){
		ServerCore.forgePostItemMobGriefingCheck((Mob)(Object)this);
	}

}

==> open-parties-and-claims-forge-1.20.6-0.25.8-sources.jar: xaero/pac/common/mixin/MixinForgeMob.java <==
/*
 * Open Parties and Claims - adds chunk claims and player parties to Minecraft
 * Copyright (C) 2022-2025, Xaero <xaero1996@gmail.com> and contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of version 3 of the GNU Lesser General Public License
 * (LGPL-3.0-only) as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received copies of the GNU Lesser General Public License
 * and the GNU General Public License along with this program.
 * If not, see <https://www.gnu.org/licenses/>.
 */

package xaero.pac.common.mixin;

import net.minecraft.core.Vec3i;
import net.minecraft.world.entity.Mob;
import net.minecraft.world.entity.item.ItemEntity;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.LocalCapture;
import xaero.pac.common.server.core.ServerCore;

import java.util.Iterator;
import java.util.List;

@Mixin(value = Mob.class, priority = 1000001)
public class MixinForgeMob {

	@Inject(method = "aiStep", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/entity/LivingEntity;aiStep()V", shift = At.Shift.AFTER))
	public void onAiStepPre(CallbackInfo ci){
		ServerCore.forgePreItemMobGriefingCheck((Mob)(Object)this);
	}

	@Inject(method = "aiStep", at = @At("RETURN"))
	public void onAiStepPost(CallbackInfo ci){
		ServerCore.forgePostItemMobGriefingCheck((Mob)(Object)this);
	}

	@Inject(method = "aiStep", locals = LocalCapture.CAPTURE_FAILSOFT, at = @At(value = "INVOKE", target = "Lnet/minecraft/world/entity/Mob;pickUpItem(Lnet/minecraft/world/entity/item/ItemEntity;)V"), cancellable = true)
	public void onAiStepItemPickup(CallbackInfo ci, Vec3i vec3i, Iterator var2, ItemEntity itemEntity){//different from fabric parameters
		if(ServerCore.onMobItemPickup(itemEntity, (Mob)(Object)this))
			ci.cancel();
	}

}
